Edison plug-in for Thonny
==========================

This is a plug-in for `Thonny IDE <http://thonny.org>`_, which adds possibility to program `Edison robot <https://meetedison.com/>`_ in a `Python-like language <https://meetedison.com/meet-edpy-python-programming-edison/>`_ using `EdPy library <https://github.com/Bdanilko/EdPy/>`_. 

**NB! At the moment the plug-in is very early stage and probably works only on Windows! The user interface will change considerably**

Usage
------

#. Install Thonny 2.1 or later
#. Select Tools => Manage plug-ins...
#. enter ``thonny-edison`` to search box and press ENTER
#. Install the plug-in
#. Restart Thonny

After this you should see Edison programming command in Tools menu

